@@ -9,14 +9,21 @@
 
 __all__ = ['Resource']
 
+import globals
+
 
 class Resource(object):
 
     def __init__(self, id=None, name=None):
-        self.id = id if not id is None else unique_task_id()
-        if name is None:
-            self.name = "Resource"+str(self.id)
+        if not id is None:
+            self.id = id
         else:
+            self.id = globals.unique_id()
+        if name is None:
+            self.description = "Resource"+str(self.id)
+            self.name = self.description
+        else:
+            self.description = name
             self.name = name
         self._busy=False
 
